#!/bin/sh

# Performance Data Analyzer (PDA)
# Copyright (c) 2006-2013 by Nicolas Michael
# License:      GNU General Public License v2
# Website:      http://pda.nmichael.de/

SCRIPT=`basename $0`

# GC Log File
GCLOG=javagc.log
DEMOLOG=demo.csv

# Runtime
if [ "$1" != "" ] ; then
  RUNTIME=$1
else
  RUNTIME=5
fi


# PDA Installation Directory
if [ "$PDA_HOME" = "" ] ; then
  PDA_HOME=`dirname $0`
fi

# Other Directories
PDA_PROGRAM=$PDA_HOME/program
PDA_PARSERS=$PDA_HOME/parsers

# Java Args and Classpath
PDA_JAVA_ARGS="-Xms50M -Xmx150M -XX:NewSize=20M -XX:MaxNewSize=20M -XX:SurvivorRatio=2 -XX:TargetSurvivorRatio=90 -XX:+UseSerialGC -XX:MaxTenuringThreshold=15 -XX:MinHeapFreeRatio=10 -XX:MaxHeapFreeRatio=20 -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:${GCLOG:?}"
PDA_CLASSPATH="$PDA_PROGRAM/pda.jar"

# Logging Info
echo "[$SCRIPT] Creating a GC Logfile ..."
echo "[$SCRIPT] GC Log File          : $GCLOG"
echo "[$SCRIPT] Demo CSV File        : $DEMOLOG"
echo "[$SCRIPT] Runtime              : $RUNTIME min"
echo "[$SCRIPT] Running              : java $PDA_JAVA_ARGS -cp $PDA_CLASSPATH de.nmichael.pda.demo.WriteJavaGC ${RUNTIME:?}"

java $PDA_JAVA_ARGS -cp $PDA_CLASSPATH de.nmichael.pda.demo.WriteJavaGC ${RUNTIME:?} ${DEMOLOG:?}

echo "[$SCRIPT] Your GC Log File is  : $GCLOG"
echo "[$SCRIPT] Your Demo CSV File is: $DEMOLOG"
echo "[$SCRIPT] Done."
